use sea_orm_migration::prelude::*;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(Hersteller::Table)
                    .if_not_exists()
                    .col(
                        ColumnDef::new(Hersteller::Id)
                            .integer()
                            .not_null()
                            .auto_increment()
                            .primary_key(),
                    )
                    .col(ColumnDef::new(Hersteller::Name).string().not_null())
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(Hersteller::Table).to_owned())
            .await
    }
}

#[derive(Iden)]
#[iden(rename = "hersteller")]
pub enum Hersteller {
    Table,
    Id,
    Name,
}
