use sea_orm_migration::prelude::*;

use super::{m20240602_100749_create_typ::Typ, m20240602_100754_create_hersteller::Hersteller};

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(Modell::Table)
                    .if_not_exists()
                    .col(
                        ColumnDef::new(Modell::Id)
                            .integer()
                            .not_null()
                            .auto_increment()
                            .primary_key(),
                    )
                    .col(ColumnDef::new(Modell::Name).string().not_null())
                    .col(ColumnDef::new(Modell::TypId).integer().not_null())
                    .col(ColumnDef::new(Modell::HerstellerId).integer().not_null())
                    .foreign_key(
                        ForeignKey::create()
                            .name("fk_typ")
                            .from(Modell::Table, Modell::TypId)
                            .to(Typ::Table, Typ::Id),
                    )
                    .foreign_key(
                        ForeignKey::create()
                            .name("fk_hersteller")
                            .from(Modell::Table, Modell::HerstellerId)
                            .to(Hersteller::Table, Hersteller::Id),
                    )
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(Modell::Table).to_owned())
            .await
    }
}

#[derive(Iden)]
#[iden(rename = "modelle")]
enum Modell {
    Table,
    Id,
    Name,
    TypId,
    HerstellerId,
}
